# exemplo_pacote

[![Build Status](https://app.travis-ci.com/Heber3000/exemplo_pacote.svg?branch=main)](https://app.travis-ci.com/Heber3000/exemplo_pacote)
[![Updates](https://pyup.io/repos/github/Heber3000/exemplo_pacote/shield.svg)](https://pyup.io/repos/github/Heber3000/exemplo_pacote/)
[![Python 3](https://pyup.io/repos/github/Heber3000/exemplo_pacote/python-3-shield.svg)](https://pyup.io/repos/github/Heber3000/exemplo_pacote/)

